Assorted spelling fixes & co.

Francois Gouget fgouget at free.fr
Mon Sep 26 17:14:10 CDT 2011


---
 dlls/comctl32/tests/rebar.c                |    2 +-
 dlls/comctl32/tests/status.c               |    2 +-
 dlls/comctl32/tests/treeview.c             |    6 +++---
 dlls/kernel32/tests/sync.c                 |    4 ++--
 dlls/quartz/tests/avisplitter.c            |   18 +++++++++---------
 dlls/shlwapi/string.c                      |    2 +-
 dlls/shlwapi/tests/ordinal.c               |    4 ++--
 programs/winemenubuilder/winemenubuilder.c |    8 ++++----
 8 files changed, 23 insertions(+), 23 deletions(-)

diff --git a/dlls/comctl32/tests/rebar.c b/dlls/comctl32/tests/rebar.c
index 5efe940..88c931c 100644
--- a/dlls/comctl32/tests/rebar.c
+++ b/dlls/comctl32/tests/rebar.c
@@ -1115,7 +1115,7 @@ START_TEST(rebar)
 
     init_system_font_height();
 
-    /* LoadLibrary is needed. This file has no references to functions in comctl32 */
+    /* LoadLibrary is needed. This file has no reference to functions in comctl32 */
     hComctl32 = LoadLibraryA("comctl32.dll");
     pInitCommonControlsEx = (void*)GetProcAddress(hComctl32, "InitCommonControlsEx");
     if (!pInitCommonControlsEx)
diff --git a/dlls/comctl32/tests/status.c b/dlls/comctl32/tests/status.c
index 0eaae59..6e5a3e7 100644
--- a/dlls/comctl32/tests/status.c
+++ b/dlls/comctl32/tests/status.c
@@ -460,7 +460,7 @@ static void test_status_ownerdraw(void)
     r = SendMessage(hWndStatus, SB_SETTEXT, SBT_OWNERDRAW, (LPARAM)statustext);
     ok( r == TRUE, "Sendmessage returned %d, expected 1\n", r);
     ok( 1 == g_wmdrawitm_ctr, "got %d drawitem messages expected 1\n", g_wmdrawitm_ctr);
-    /* ;and again */
+    /* and again */
     g_wmdrawitm_ctr = 0;
     r = SendMessage(hWndStatus, SB_SETTEXT, SBT_OWNERDRAW, (LPARAM)statustext);
     ok( r == TRUE, "Sendmessage returned %d, expected 1\n", r);
diff --git a/dlls/comctl32/tests/treeview.c b/dlls/comctl32/tests/treeview.c
index 588a5ca..fd4a6ce 100644
--- a/dlls/comctl32/tests/treeview.c
+++ b/dlls/comctl32/tests/treeview.c
@@ -1129,7 +1129,7 @@ static void test_expandinvisible(void)
 
     hTree = create_treeview_control(0);
 
-    /* The test builds the following tree and expands then node 1, while node 0 is collapsed.
+    /* The test builds the following tree and expands node 1, while node 0 is collapsed.
      *
      * 0
      * |- 1
@@ -1385,7 +1385,7 @@ static void test_expandnotify(void)
     ret = SendMessageA(hTree, TVM_GETITEMA, 0, (LPARAM)&item);
     expect(TRUE, ret);
     ok((item.state & TVIS_EXPANDED) == 0, "expected collapsed\n");
-    /* all next collapse/expand attempts won't produce any notifications,
+    /* all further collapse/expand attempts won't produce any notifications,
        the only way is to reset with all children removed */
     ok_sequence(sequences, PARENT_SEQ_INDEX, empty_seq, "collapse after expand notifications", FALSE);
 
@@ -1480,7 +1480,7 @@ static void test_TVS_SINGLEEXPAND(void)
     ok(ret, "got %d\n", ret);
     ok_sequence(sequences, PARENT_SEQ_INDEX, parent_singleexpand_seq, "singleexpand notifications", FALSE);
 
-    /* a workaround for NT4 that sends expanding notification when nothing is about to expand */
+    /* a workaround for NT4 that sends expand notifications when nothing is about to expand */
     ret = SendMessageA(hTree, TVM_DELETEITEM, 0, (LPARAM)hRoot);
     ok(ret, "got %d\n", ret);
     fill_tree(hTree);
diff --git a/dlls/kernel32/tests/sync.c b/dlls/kernel32/tests/sync.c
index 98d996f..07bc2ca 100644
--- a/dlls/kernel32/tests/sync.c
+++ b/dlls/kernel32/tests/sync.c
@@ -135,7 +135,7 @@ static void test_mutex(void)
     ok(hCreated != NULL, "CreateMutex failed with error %d\n", GetLastError());
 
     hOpened = OpenMutex(0, FALSE, "WineTestMutex");
-    ok(hOpened == NULL, "OpenMutex succeded\n");
+    ok(hOpened == NULL, "OpenMutex succeeded\n");
 
     hOpened = OpenMutex(GENERIC_EXECUTE, FALSE, "WineTestMutex");
     ok(hOpened != NULL, "OpenMutex failed with error %d\n", GetLastError());
@@ -171,7 +171,7 @@ static void test_mutex(void)
         }
     }
 
-    ok( failed == 0x0de0fffe, "open succeded when it shouldn't: %x\n", failed);
+    ok( failed == 0x0de0fffe, "open succeeded when it shouldn't: %x\n", failed);
 
     ret = ReleaseMutex(hCreated);
     ok(!ret && (GetLastError() == ERROR_NOT_OWNER),
diff --git a/dlls/shlwapi/string.c b/dlls/shlwapi/string.c
index d0f0f0e..3519b34 100644
--- a/dlls/shlwapi/string.c
+++ b/dlls/shlwapi/string.c
@@ -2364,7 +2364,7 @@ LPWSTR WINAPI StrFormatByteSizeW(LONGLONG llBytes, LPWSTR lpszDest, UINT cchMax)
    * counts that lie exactly on a 1024 byte boundary.
    */
   if (i > 8)
-    dBytes = (double)(llBytes >> 20) + 0.001; /* Scale down by I MB */
+    dBytes = (double)(llBytes >> 20) + 0.001; /* Scale down by 1 MB */
   else
     dBytes = (double)llBytes + 0.00001;
 
diff --git a/dlls/shlwapi/tests/ordinal.c b/dlls/shlwapi/tests/ordinal.c
index 8316112..593307e 100644
--- a/dlls/shlwapi/tests/ordinal.c
+++ b/dlls/shlwapi/tests/ordinal.c
@@ -2855,7 +2855,7 @@ static void test_SHGetShellKey(void)
 
     hkey = pSHGetShellKey(SHKEY_Root_HKLM, NULL, FALSE);
     ok(hkey != NULL, "Can't open key\n");
-    ok(SUCCEEDED(RegDeleteKeyW(hkey, WineTestW)), "Can't delte key\n");
+    ok(SUCCEEDED(RegDeleteKeyW(hkey, WineTestW)), "Can't delete key\n");
     RegCloseKey(hkey);
 
     hkey = pSHGetShellKey(SHKEY_Root_HKLM, WineTestW, TRUE);
@@ -2911,7 +2911,7 @@ static void test_SHGetShellKey(void)
 
     hkey = pSHGetShellKey(SHKEY_Root_HKLM, NULL, FALSE);
     ok(hkey != NULL, "Can't create key\n");
-    ok(SUCCEEDED(RegDeleteKeyW(hkey, WineTestW)), "Can't delte key\n");
+    ok(SUCCEEDED(RegDeleteKeyW(hkey, WineTestW)), "Can't delete key\n");
     RegCloseKey(hkey);
 }
 
diff --git a/programs/winemenubuilder/winemenubuilder.c b/programs/winemenubuilder/winemenubuilder.c
index d6b7b39..a8b2b0d 100644
--- a/programs/winemenubuilder/winemenubuilder.c
+++ b/programs/winemenubuilder/winemenubuilder.c
@@ -369,7 +369,7 @@ static WCHAR* utf8_chars_to_wchars(LPCSTR string)
  * FIXME: should not use stdio
  */
 
-static HRESULT convert_to_native_icon(IStream *icoFile, int *indeces, int numIndeces,
+static HRESULT convert_to_native_icon(IStream *icoFile, int *indices, int numIndices,
                                       const CLSID *outputFormat, const char *outputFileName, LPCWSTR commentW)
 {
     WCHAR *dosOutputFileName = NULL;
@@ -420,7 +420,7 @@ static HRESULT convert_to_native_icon(IStream *icoFile, int *indeces, int numInd
         goto end;
     }
 
-    for (i = 0; i < numIndeces; i++)
+    for (i = 0; i < numIndices; i++)
     {
         IWICBitmapFrameDecode *sourceFrame = NULL;
         IWICBitmapSource *sourceBitmap = NULL;
@@ -428,10 +428,10 @@ static HRESULT convert_to_native_icon(IStream *icoFile, int *indeces, int numInd
         IPropertyBag2 *options = NULL;
         UINT width, height;
 
-        hr = IWICBitmapDecoder_GetFrame(decoder, indeces[i], &sourceFrame);
+        hr = IWICBitmapDecoder_GetFrame(decoder, indices[i], &sourceFrame);
         if (FAILED(hr))
         {
-            WINE_ERR("error 0x%08X getting frame %d\n", hr, indeces[i]);
+            WINE_ERR("error 0x%08X getting frame %d\n", hr, indices[i]);
             goto endloop;
         }
         hr = WICConvertBitmapSource(&GUID_WICPixelFormat32bppBGRA, (IWICBitmapSource*)sourceFrame, &sourceBitmap);
diff --git a/dlls/quartz/tests/avisplitter.c b/dlls/quartz/tests/avisplitter.c
index 3a0a9e2..59e277e 100644
--- a/dlls/quartz/tests/avisplitter.c
+++ b/dlls/quartz/tests/avisplitter.c
@@ -173,10 +173,10 @@ static const WCHAR wfile[] = {'t','e','s','t','.','a','v','i',0};
 static const char afile[] = "test.avi";
 
 /* This test doesn't use the quartz filtergraph because it makes it impossible
- * to be certain that a thread is really one owned by the avi splitter
- * A lot of the decoder filters will also have their own thread, and windows'
+ * to be certain that a thread is really one owned by the avi splitter.
+ * A lot of the decoder filters will also have their own thread, and Windows'
  * filtergraph has a separate thread for start/stop/seeking requests.
- * By avoiding the filtergraph all together and connecting streams directly to
+ * By avoiding the filtergraph altogether and connecting streams directly to
  * the null renderer I am sure that this is not the case here.
  */
 static void test_threads(void)
@@ -200,7 +200,7 @@ static void test_threads(void)
         return;
     }
 
     /* Before doing anything (number of threads at the start differs per OS) */
     baselevel = count_threads();
 
     file = CreateFileW(wfile, GENERIC_READ, FILE_SHARE_READ|FILE_SHARE_WRITE,
@@ -280,7 +280,7 @@ static void test_threads(void)
 
     curlevel = count_threads();
     ok(curlevel == baselevel,
-        "Amount of threads should be %d not %d\n", baselevel, curlevel);
+        "The thread count should be %d not %d\n", baselevel, curlevel);
 
     hr = IPin_Connect(filepin, avipin, NULL);
     ok(hr == S_OK, "Could not connect: %08x\n", hr);
@@ -290,7 +290,7 @@ static void test_threads(void)
     expected = 1 + baselevel;
     curlevel = count_threads();
     ok(curlevel == expected,
-        "Amount of threads should be %d not %d\n", expected, curlevel);
+        "The thread count should be %d not %d\n", expected, curlevel);
 
     IUnknown_Release(avipin);
     avipin = NULL;
@@ -346,7 +346,7 @@ static void test_threads(void)
     if (hr != S_OK)
         goto fail2;
     /* At this point there is a minimalistic connected avi splitter that can
-     * Be used for all sorts of source filter tests, however that still needs
+     * be used for all sorts of source filter tests. However that still needs
      * to be written at a later time.
      *
      * Interesting tests:
@@ -366,7 +366,7 @@ static void test_threads(void)
 
     curlevel = count_threads();
     ok(curlevel == expected,
-        "Amount of threads should be %d not %d\n", expected, curlevel);
+        "The thread count should be %d not %d\n", expected, curlevel);
 
     IBaseFilter_Pause(pavi);
     IBaseFilter_Pause(preader);
@@ -442,7 +442,7 @@ fail:
     curlevel = count_threads();
     todo_wine
     ok(curlevel == baselevel,
-        "Amount of threads should be %d not %d\n", baselevel, curlevel);
+        "The thread count should be %d not %d\n", baselevel, curlevel);
 }
 
 START_TEST(avisplitter)
@@ -200,7 +200,7 @@ static void test_threads(void)
     }
 
-    /* Before doing anything (number of threads at the start differs per OS) */
+    /* Before doing anything (the thread count at the start differs per OS) */
     baselevel = count_threads();
 
-- 
1.7.5.4



More information about the wine-patches mailing list